@@ -777,8 +777,13 @@ bool KEduVocKvtmlReader::readExpressionChildAttributes( QDomElement &domElementE
     if ( !attribute.isNull() ) {
         QString s = attribute.value();
         if (( pos = s.indexOf( ';' ) ) >= 1 ) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
             grade = s.leftRef( pos ).toInt();
             rev_grade = s.midRef( pos + 1, s.length() ).toInt();
+#else
+            grade = QStringView(s).left( pos ).toInt();
+            rev_grade = QStringView(s).mid( pos + 1, s.length() ).toInt();
+#endif
         } else
             grade = s.toInt();
     }
@@ -789,8 +794,13 @@ bool KEduVocKvtmlReader::readExpressionChildAttributes( QDomElement &domElementE
     if ( !attribute.isNull() ) {
         QString s = attribute.value();
         if (( pos = s.indexOf( ';' ) ) >= 1 ) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
             count = s.leftRef( pos ).toInt();
             rev_count = s.midRef( pos + 1, s.length() ).toInt();
+#else
+            count = QStringView(s).left( pos ).toInt();
+            rev_count = QStringView(s).mid( pos + 1, s.length() ).toInt();
+#endif
         } else
             count = s.toInt();
     }
@@ -801,22 +811,32 @@ bool KEduVocKvtmlReader::readExpressionChildAttributes( QDomElement &domElementE
     if ( !attribute.isNull() ) {
         QString s = attribute.value();
         if (( pos = s.indexOf( ';' ) ) >= 1 ) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
             bcount = s.leftRef( pos ).toInt();
             rev_bcount = s.midRef( pos + 1, s.length() ).toInt();
+#else
+            bcount = QStringView(s).left( pos ).toInt();
+            rev_bcount = QStringView(s).mid( pos + 1, s.length() ).toInt();
+#endif
         } else
             bcount = s.toInt();
     }
 
-    date.setTime_t( 0 );
-    rev_date.setTime_t( 0 );
+    date = QDateTime::fromSecsSinceEpoch(0);
+    rev_date = QDateTime::fromSecsSinceEpoch( 0 );
     attribute = domElementExpressionChild.attributeNode( KV_DATE );
     if ( !attribute.isNull() ) {
         QString s = attribute.value();
         if (( pos = s.indexOf( ';' ) ) >= 1 ) {
-            date.setTime_t( s.leftRef( pos ).toInt() );
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+            date = QDateTime::fromSecsSinceEpoch( s.leftRef( pos ).toInt() );
             rev_date.setTime_t( s.midRef( pos + 1, s.length() ).toInt() );
+#else
+            date = QDateTime::fromSecsSinceEpoch( QStringView(s).left( pos ).toInt() );
+            rev_date = QDateTime::fromSecsSinceEpoch( QStringView(s).mid( pos + 1, s.length() ).toInt() );
+#endif
         } else
-            date.setTime_t( s.toInt() );
+            date= QDateTime::fromSecsSinceEpoch( s.toInt() );
     }
 
     attribute = domElementExpressionChild.attributeNode( KV_DATE2 );
